var searchData=
[
  ['abbreviatestring',['abbreviateString',['../interfacecom_1_1sun_1_1star_1_1util_1_1XStringAbbreviation.html#ac5ac0e1f472e69cd5fafe1c600f7ef17',1,'com::sun::star::util::XStringAbbreviation']]],
  ['abort',['abort',['../interfacecom_1_1sun_1_1star_1_1ucb_1_1XCommandProcessor.html#a684ca1512b4a6b827fefadda3cff3aa3',1,'com::sun::star::ucb::XCommandProcessor']]],
  ['aborted',['aborted',['../interfacecom_1_1sun_1_1star_1_1sheet_1_1XRangeSelectionListener.html#a3f10dd90a57da5acf3d8c81cf30a51e3',1,'com::sun::star::sheet::XRangeSelectionListener']]],
  ['abortrangeselection',['abortRangeSelection',['../interfacecom_1_1sun_1_1star_1_1sheet_1_1XRangeSelection.html#ae3dcc3cb8ec85ea11cdda640ca05a59b',1,'com::sun::star::sheet::XRangeSelection']]],
  ['absolute',['absolute',['../interfacecom_1_1sun_1_1star_1_1sdbc_1_1XResultSet.html#ab24122b4491fb304e0ea5738e0008087',1,'com::sun::star::sdbc::XResultSet']]],
  ['accept',['accept',['../interfacecom_1_1sun_1_1star_1_1connection_1_1XAcceptor.html#a11ff00bac491281a0232569cf00222ac',1,'com::sun::star::connection::XAcceptor::accept()'],['../interfacecom_1_1sun_1_1star_1_1auth_1_1XSSOAcceptorContext.html#a36d68d793f53799294b1eb740fb78794',1,'com::sun::star::auth::XSSOAcceptorContext::accept()']]],
  ['acceptdrag',['acceptDrag',['../interfacecom_1_1sun_1_1star_1_1datatransfer_1_1dnd_1_1XDropTargetDragContext.html#ab9463c00d53cf6f6138d780340cbb399',1,'com::sun::star::datatransfer::dnd::XDropTargetDragContext']]],
  ['acceptdrop',['acceptDrop',['../interfacecom_1_1sun_1_1star_1_1datatransfer_1_1dnd_1_1XDropTargetDropContext.html#a301880bb3010fb376add2776545f3b2e',1,'com::sun::star::datatransfer::dnd::XDropTargetDropContext']]],
  ['acceptsurl',['acceptsURL',['../interfacecom_1_1sun_1_1star_1_1sdbc_1_1XDriver.html#a55ed4d683f4a2dc5e04648d688bff793',1,'com::sun::star::sdbc::XDriver']]],
  ['acquire',['acquire',['../interfacecom_1_1sun_1_1star_1_1uno_1_1XInterface.html#af9f5b35a212d21af601a8213ed325871',1,'com::sun::star::uno::XInterface']]],
  ['actionperformed',['actionPerformed',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XActionListener.html#a8e3891ca5fc68ff0d84b7c5ad2716b5d',1,'com::sun::star::awt::XActionListener']]],
  ['actionredone',['actionRedone',['../interfacecom_1_1sun_1_1star_1_1document_1_1XUndoManagerListener.html#a38462af309ce44845018d2c31bf23793',1,'com::sun::star::document::XUndoManagerListener']]],
  ['actionundone',['actionUndone',['../interfacecom_1_1sun_1_1star_1_1document_1_1XUndoManagerListener.html#a8d5c2bec557cb1971f8de6189ac55201',1,'com::sun::star::document::XUndoManagerListener']]],
  ['activate',['activate',['../interfacecom_1_1sun_1_1star_1_1loader_1_1XImplementationLoader.html#a03775cce35d5cdad306410c24a9655c6',1,'com::sun::star::loader::XImplementationLoader::activate()'],['../interfacecom_1_1sun_1_1star_1_1frame_1_1XFrame.html#a8011fcbeb5efeda20bd2dbffbbb70165',1,'com::sun::star::frame::XFrame::activate()'],['../interfacecom_1_1sun_1_1star_1_1presentation_1_1XSlideShowController.html#a8011fcbeb5efeda20bd2dbffbbb70165',1,'com::sun::star::presentation::XSlideShowController::activate()'],['../interfacecom_1_1sun_1_1star_1_1ui_1_1XDeck.html#a765d388d02ef5dee3800e170b6891f92',1,'com::sun::star::ui::XDeck::activate()']]],
  ['activated',['activated',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XTabListener.html#a5da2f4dede929d10ab38a9055b260369',1,'com::sun::star::awt::XTabListener::activated()'],['../interfacecom_1_1sun_1_1star_1_1embed_1_1XHatchWindowController.html#a244e631e4637625aaca7abf94c04d4d1',1,'com::sun::star::embed::XHatchWindowController::activated()']]],
  ['activatefirst',['activateFirst',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XTabController.html#ac783b1d7f5af82a68e7c3b2bfe865417',1,'com::sun::star::awt::XTabController']]],
  ['activatelast',['activateLast',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XTabController.html#afee59b20c211248d0258f05d19050cd0',1,'com::sun::star::awt::XTabController']]],
  ['activatenextcontrol',['activateNextControl',['../interfacecom_1_1sun_1_1star_1_1inspection_1_1XPropertyControlContext.html#ad724bb8bc27e3360201f096239bb4237',1,'com::sun::star::inspection::XPropertyControlContext']]],
  ['activatepage',['activatePage',['../interfacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1XWizardPage.html#a21c43b9ab38e73f1451e937f27c47b76',1,'com::sun::star::ui::dialogs::XWizardPage']]],
  ['activatepath',['activatePath',['../interfacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1XWizard.html#a8445bf6dbcea4d18d21f9dc9627e143e',1,'com::sun::star::ui::dialogs::XWizard']]],
  ['activateremotecontentproviders',['activateRemoteContentProviders',['../interfacecom_1_1sun_1_1star_1_1ucb_1_1XRemoteContentProviderActivator.html#aff0251c05520be8121701546c5f24a0d',1,'com::sun::star::ucb::XRemoteContentProviderActivator']]],
  ['activatetab',['activateTab',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XSimpleTabController.html#ac8f58565416bfbda897b4656a1e552cd',1,'com::sun::star::awt::XSimpleTabController']]],
  ['activatetaborder',['activateTabOrder',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XTabController.html#ad0f981dd3546365aa7c48e005fa56a2b',1,'com::sun::star::awt::XTabController']]],
  ['activatinginplace',['activatingInplace',['../interfacecom_1_1sun_1_1star_1_1embed_1_1XInplaceClient.html#a18c3acb62607beb3204a7ecc13cf8547',1,'com::sun::star::embed::XInplaceClient']]],
  ['activatingui',['activatingUI',['../interfacecom_1_1sun_1_1star_1_1embed_1_1XInplaceClient.html#afabc6486a387b993bcde4033f6b0d110',1,'com::sun::star::embed::XInplaceClient']]],
  ['activespreadsheetchanged',['activeSpreadsheetChanged',['../interfacecom_1_1sun_1_1star_1_1sheet_1_1XActivationEventListener.html#aab6793f408b9ef45ad9c6e6aabf6afb0',1,'com::sun::star::sheet::XActivationEventListener']]],
  ['actuatingpropertychanged',['actuatingPropertyChanged',['../interfacecom_1_1sun_1_1star_1_1inspection_1_1XPropertyHandler.html#a90db1424b4dedda34438a3b643ef80cc',1,'com::sun::star::inspection::XPropertyHandler']]],
  ['add',['add',['../interfacecom_1_1sun_1_1star_1_1drawing_1_1XShapes.html#ad442c8e00764710af7b9398425311a12',1,'com::sun::star::drawing::XShapes::add()'],['../interfacecom_1_1sun_1_1star_1_1linguistic2_1_1XDictionary.html#a8ef2f77c50a773e81d85eddd3e645d92',1,'com::sun::star::linguistic2::XDictionary::add()'],['../interfacecom_1_1sun_1_1star_1_1linguistic2_1_1XDictionary1.html#a8ef2f77c50a773e81d85eddd3e645d92',1,'com::sun::star::linguistic2::XDictionary1::add()'],['../interfacecom_1_1sun_1_1star_1_1task_1_1XPasswordContainer.html#a2478645f2de945f27c51c53abe4cd5c9',1,'com::sun::star::task::XPasswordContainer::add()']]],
  ['addaccessibleeventlistener',['addAccessibleEventListener',['../interfacecom_1_1sun_1_1star_1_1accessibility_1_1XAccessibleEventBroadcaster.html#ae41c29350e4281b778463ac83305a512',1,'com::sun::star::accessibility::XAccessibleEventBroadcaster']]],
  ['addactionlistener',['addActionListener',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XButton.html#a7ffbc5096d58bb272723ad6d20e1e5e8',1,'com::sun::star::awt::XButton::addActionListener()'],['../interfacecom_1_1sun_1_1star_1_1awt_1_1XComboBox.html#a7ffbc5096d58bb272723ad6d20e1e5e8',1,'com::sun::star::awt::XComboBox::addActionListener()'],['../interfacecom_1_1sun_1_1star_1_1awt_1_1XFixedHyperlink.html#a7ffbc5096d58bb272723ad6d20e1e5e8',1,'com::sun::star::awt::XFixedHyperlink::addActionListener()'],['../interfacecom_1_1sun_1_1star_1_1awt_1_1XImageButton.html#a7ffbc5096d58bb272723ad6d20e1e5e8',1,'com::sun::star::awt::XImageButton::addActionListener()'],['../interfacecom_1_1sun_1_1star_1_1awt_1_1XListBox.html#a7ffbc5096d58bb272723ad6d20e1e5e8',1,'com::sun::star::awt::XListBox::addActionListener()'],['../interfacecom_1_1sun_1_1star_1_1inspection_1_1XHyperlinkControl.html#a74ecae386bb0df48f0c08877ed746d92',1,'com::sun::star::inspection::XHyperlinkControl::addActionListener()']]],
  ['addactionlock',['addActionLock',['../interfacecom_1_1sun_1_1star_1_1document_1_1XActionLockable.html#ae524582ad7f13a8cc05cb9236e7a7635',1,'com::sun::star::document::XActionLockable']]],
  ['addactivatelistener',['addActivateListener',['../interfacecom_1_1sun_1_1star_1_1form_1_1runtime_1_1XFormController.html#a78f46eba46a4d71fcfe3768cca3387a8',1,'com::sun::star::form::runtime::XFormController::addActivateListener()'],['../interfacecom_1_1sun_1_1star_1_1form_1_1XFormController.html#a688b0a9af936e24eb9d02e6a44a27319',1,'com::sun::star::form::XFormController::addActivateListener()']]],
  ['addactivationeventlistener',['addActivationEventListener',['../interfacecom_1_1sun_1_1star_1_1sheet_1_1XActivationBroadcaster.html#a194b20848ed5aeee85b4eb4a39977b02',1,'com::sun::star::sheet::XActivationBroadcaster']]],
  ['addadjustmentlistener',['addAdjustmentListener',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XScrollBar.html#a96e6f8b17b97ed1116348b912417733a',1,'com::sun::star::awt::XScrollBar::addAdjustmentListener()'],['../interfacecom_1_1sun_1_1star_1_1awt_1_1XSpinValue.html#acda38a94dcecdee1580af9e621ee41d9',1,'com::sun::star::awt::XSpinValue::addAdjustmentListener()']]],
  ['addapproveactionlistener',['addApproveActionListener',['../interfacecom_1_1sun_1_1star_1_1form_1_1XApproveActionBroadcaster.html#ae3c2fe3ff16d3088ed530dc8b7ad8bad',1,'com::sun::star::form::XApproveActionBroadcaster']]],
  ['addattachment',['addAttachment',['../interfacecom_1_1sun_1_1star_1_1mail_1_1XMailMessage.html#aad6194cd8c1f847c71483433ddb2197c',1,'com::sun::star::mail::XMailMessage']]],
  ['addauthortotrustedsources',['addAuthorToTrustedSources',['../interfacecom_1_1sun_1_1star_1_1security_1_1XDocumentDigitalSignatures.html#a5b38533be6285ac061fa104391763df3',1,'com::sun::star::security::XDocumentDigitalSignatures']]],
  ['addbatch',['addBatch',['../interfacecom_1_1sun_1_1star_1_1sdbc_1_1XBatchExecution.html#a6ad6e03503d1c780380cf9115087578c',1,'com::sun::star::sdbc::XBatchExecution::addBatch()'],['../interfacecom_1_1sun_1_1star_1_1sdbc_1_1XPreparedBatchExecution.html#a403a78f23cd236be35da641fbe511b4c',1,'com::sun::star::sdbc::XPreparedBatchExecution::addBatch()']]],
  ['addbccrecipient',['addBccRecipient',['../interfacecom_1_1sun_1_1star_1_1mail_1_1XMailMessage.html#ab80768ff13f5fb64c09cecce7ac3d166',1,'com::sun::star::mail::XMailMessage']]],
  ['addblocker',['addBlocker',['../interfacecom_1_1sun_1_1star_1_1xml_1_1crypto_1_1sax_1_1XSAXEventKeeper.html#a920be90d99f09415b904535edecfe94b',1,'com::sun::star::xml::crypto::sax::XSAXEventKeeper']]],
  ['addborder',['addBorder',['../interfacecom_1_1sun_1_1star_1_1drawing_1_1framework_1_1XPaneBorderPainter.html#a94a389c5be60939c9a05f70c2dfab808',1,'com::sun::star::drawing::framework::XPaneBorderPainter']]],
  ['addborderresizelistener',['addBorderResizeListener',['../interfacecom_1_1sun_1_1star_1_1frame_1_1XControllerBorder.html#aa774a1b0072c4216adf3303d9ef67a4a',1,'com::sun::star::frame::XControllerBorder']]],
  ['addbottom',['addBottom',['../interfacecom_1_1sun_1_1star_1_1drawing_1_1XShapes2.html#a0601637541f5b16cd7be0eba9ca871d0',1,'com::sun::star::drawing::XShapes2']]],
  ['addcallback',['addCallback',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XRequestCallback.html#acaac2cfd88943505bf3abb3bac2b6fda',1,'com::sun::star::awt::XRequestCallback']]],
  ['addccrecipient',['addCcRecipient',['../interfacecom_1_1sun_1_1star_1_1mail_1_1XMailMessage.html#a6126b466ad85318d40556a171065b131',1,'com::sun::star::mail::XMailMessage']]],
  ['addcertificate',['addCertificate',['../interfacecom_1_1sun_1_1star_1_1security_1_1XCertificateContainer.html#a8b81f7d4bfcc36c5498b309c9df12b68',1,'com::sun::star::security::XCertificateContainer']]],
  ['addchangelistener',['addChangeListener',['../interfacecom_1_1sun_1_1star_1_1form_1_1XChangeBroadcaster.html#a3fe7930accc09e33cd2fae28f502c247',1,'com::sun::star::form::XChangeBroadcaster']]],
  ['addchangeslistener',['addChangesListener',['../interfacecom_1_1sun_1_1star_1_1configuration_1_1backend_1_1XBackendChangesNotifier.html#a275603436133318db5c8a5fd85e81d9b',1,'com::sun::star::configuration::backend::XBackendChangesNotifier::addChangesListener()'],['../interfacecom_1_1sun_1_1star_1_1util_1_1XChangesNotifier.html#a7d8d7e072eeaa74708c4b991317710b7',1,'com::sun::star::util::XChangesNotifier::addChangesListener()']]],
  ['addchartdatachangeeventlistener',['addChartDataChangeEventListener',['../interfacecom_1_1sun_1_1star_1_1chart_1_1XChartData.html#a32a03ffdd965653406756f687a4b6ac5',1,'com::sun::star::chart::XChartData']]],
  ['addcharttype',['addChartType',['../interfacecom_1_1sun_1_1star_1_1chart2_1_1XChartTypeContainer.html#a862f3e80c1f903b7dd1d914dfbd47a8e',1,'com::sun::star::chart2::XChartTypeContainer']]],
  ['addchildcontroller',['addChildController',['../interfacecom_1_1sun_1_1star_1_1form_1_1runtime_1_1XFormController.html#aab47f521f99fda75278bdc35ba441f8b',1,'com::sun::star::form::runtime::XFormController']]],
  ['addclipboard',['addClipboard',['../interfacecom_1_1sun_1_1star_1_1datatransfer_1_1clipboard_1_1XClipboardManager.html#af17ea2616af5b3fe4594f9f2e14ef062',1,'com::sun::star::datatransfer::clipboard::XClipboardManager']]],
  ['addclipboardlistener',['addClipboardListener',['../interfacecom_1_1sun_1_1star_1_1datatransfer_1_1clipboard_1_1XClipboardNotifier.html#a5b585ed8f677f374abdb9826bf2469df',1,'com::sun::star::datatransfer::clipboard::XClipboardNotifier']]],
  ['addcloselistener',['addCloseListener',['../interfacecom_1_1sun_1_1star_1_1util_1_1XCloseBroadcaster.html#aed88b77cbda5ecb2649e55a24b3742bc',1,'com::sun::star::util::XCloseBroadcaster']]],
  ['addcolumn',['addColumn',['../interfacecom_1_1sun_1_1star_1_1awt_1_1grid_1_1XGridColumnModel.html#ab064f180662d0e5f31536f21e9247037',1,'com::sun::star::awt::grid::XGridColumnModel::addColumn()'],['../interfacecom_1_1sun_1_1star_1_1sdb_1_1tools_1_1XTableAlteration.html#ae899239fac0712c4510649915d21676d',1,'com::sun::star::sdb::tools::XTableAlteration::addColumn()']]],
  ['addcommandinfochangelistener',['addCommandInfoChangeListener',['../interfacecom_1_1sun_1_1star_1_1ucb_1_1XCommandInfoChangeNotifier.html#abf377d06fe510fc8c00b8d2f0e0c84ad',1,'com::sun::star::ucb::XCommandInfoChangeNotifier']]],
  ['addconfigurationchangelistener',['addConfigurationChangeListener',['../interfacecom_1_1sun_1_1star_1_1drawing_1_1framework_1_1XConfigurationControllerBroadcaster.html#ac76a50a74fcc9babbe811889412af1ac',1,'com::sun::star::drawing::framework::XConfigurationControllerBroadcaster']]],
  ['addconfigurationlistener',['addConfigurationListener',['../interfacecom_1_1sun_1_1star_1_1ui_1_1XUIConfiguration.html#a8b4c2d654f49f325ec8587133843b429',1,'com::sun::star::ui::XUIConfiguration']]],
  ['addconfirmdeletelistener',['addConfirmDeleteListener',['../interfacecom_1_1sun_1_1star_1_1form_1_1XConfirmDeleteBroadcaster.html#aa02644a0e6ed33c1258635efbe732ad9',1,'com::sun::star::form::XConfirmDeleteBroadcaster']]],
  ['addconnectionlistener',['addConnectionListener',['../interfacecom_1_1sun_1_1star_1_1mail_1_1XMailService.html#a9e28e76ba5160a4bd920d5c2b3f520ed',1,'com::sun::star::mail::XMailService']]],
  ['addconsumer',['addConsumer',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XImageProducer.html#a4bcd17c46059c79a246227b003cccc11',1,'com::sun::star::awt::XImageProducer']]],
  ['addcontainerapprovelistener',['addContainerApproveListener',['../interfacecom_1_1sun_1_1star_1_1container_1_1XContainerApproveBroadcaster.html#ace9a7e3e0d26071bf2a76e50fcfd01b9',1,'com::sun::star::container::XContainerApproveBroadcaster']]],
  ['addcontainerlistener',['addContainerListener',['../interfacecom_1_1sun_1_1star_1_1container_1_1XContainer.html#a69e03a743cfa3e99935cac90b5f4e291',1,'com::sun::star::container::XContainer']]],
  ['addcontenteventlistener',['addContentEventListener',['../interfacecom_1_1sun_1_1star_1_1ucb_1_1XContent.html#ade984e206c1dfe019a3333880db04062',1,'com::sun::star::ucb::XContent']]],
  ['addcontentorstylesfile',['addContentOrStylesFile',['../interfacecom_1_1sun_1_1star_1_1rdf_1_1XDocumentMetadataAccess.html#af91ec2cd38ba6eb5380aaa8b8574134d',1,'com::sun::star::rdf::XDocumentMetadataAccess']]],
  ['addcontextchangeeventlistener',['addContextChangeEventListener',['../interfacecom_1_1sun_1_1star_1_1ui_1_1XContextChangeEventMultiplexer.html#a82299f756964bfda2d98c0a67f9c66a8',1,'com::sun::star::ui::XContextChangeEventMultiplexer']]],
  ['addcontrol',['addControl',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XControlContainer.html#a55982e96b2981729474b34dbb4f78377',1,'com::sun::star::awt::XControlContainer']]],
  ['addcoordinatesystem',['addCoordinateSystem',['../interfacecom_1_1sun_1_1star_1_1chart2_1_1XCoordinateSystemContainer.html#a3c68a5e45c52fd067f4a1ed2807224ae',1,'com::sun::star::chart2::XCoordinateSystemContainer']]],
  ['addcopytablelistener',['addCopyTableListener',['../interfacecom_1_1sun_1_1star_1_1sdb_1_1application_1_1XCopyTableWizard.html#a7fd73c114d52e6c73010adf1332f52b0',1,'com::sun::star::sdb::application::XCopyTableWizard']]],
  ['adddatabaseaccesslistener',['addDatabaseAccessListener',['../interfacecom_1_1sun_1_1star_1_1sdb_1_1XDatabaseAccess.html#a2e4ca24e3394f6aef2a102c919e8e0bc',1,'com::sun::star::sdb::XDatabaseAccess']]],
  ['adddatabaseparameterlistener',['addDatabaseParameterListener',['../interfacecom_1_1sun_1_1star_1_1form_1_1XDatabaseParameterBroadcaster2.html#aef9e0b363496d5e8f0686911ad2814fc',1,'com::sun::star::form::XDatabaseParameterBroadcaster2']]],
  ['adddatabaseregistrationslistener',['addDatabaseRegistrationsListener',['../interfacecom_1_1sun_1_1star_1_1sdb_1_1XDatabaseRegistrations.html#a5317e407ae8f4705ff8131dfcd03c8d4',1,'com::sun::star::sdb::XDatabaseRegistrations']]],
  ['adddataeditorlistener',['addDataEditorListener',['../interfacecom_1_1sun_1_1star_1_1util_1_1XDataEditor.html#a5351bdf0ab4d737085c2bb954e8c3ac1',1,'com::sun::star::util::XDataEditor']]],
  ['adddataseries',['addDataSeries',['../interfacecom_1_1sun_1_1star_1_1chart2_1_1XDataSeriesContainer.html#a16dc704f641254030f8b06eb55a2f2ef',1,'com::sun::star::chart2::XDataSeriesContainer']]],
  ['addddelink',['addDDELink',['../interfacecom_1_1sun_1_1star_1_1sheet_1_1XDDELinks.html#adffa80d8659179effbb54e7bfd6c4918',1,'com::sun::star::sheet::XDDELinks']]],
  ['adddecryptionresultlistener',['addDecryptionResultListener',['../interfacecom_1_1sun_1_1star_1_1xml_1_1crypto_1_1sax_1_1XDecryptionResultBroadcaster.html#a9eed8dd1d0662f9545f794762b280ce8',1,'com::sun::star::xml::crypto::sax::XDecryptionResultBroadcaster']]],
  ['adddialog',['addDialog',['../interfacecom_1_1sun_1_1star_1_1script_1_1XStarBasicAccess.html#af7dc6fee338e14c464fedd138b097e6f',1,'com::sun::star::script::XStarBasicAccess']]],
  ['adddictionary',['addDictionary',['../interfacecom_1_1sun_1_1star_1_1linguistic2_1_1XDictionaryList.html#af5a70c0b1cd21418fefed3f87093cbc8',1,'com::sun::star::linguistic2::XDictionaryList']]],
  ['adddictionaryeventlistener',['addDictionaryEventListener',['../interfacecom_1_1sun_1_1star_1_1linguistic2_1_1XDictionary.html#aa15cb524b46ca7e5621203ba546c08d0',1,'com::sun::star::linguistic2::XDictionary::addDictionaryEventListener()'],['../interfacecom_1_1sun_1_1star_1_1linguistic2_1_1XDictionary1.html#aa15cb524b46ca7e5621203ba546c08d0',1,'com::sun::star::linguistic2::XDictionary1::addDictionaryEventListener()']]],
  ['adddictionarylisteventlistener',['addDictionaryListEventListener',['../interfacecom_1_1sun_1_1star_1_1linguistic2_1_1XDictionaryList.html#af718cb5592917d82c1b31f313b270007',1,'com::sun::star::linguistic2::XDictionaryList']]],
  ['adddockablewindowlistener',['addDockableWindowListener',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XDockableWindow.html#a1e17909bb7db0f7991053299a2b1a082',1,'com::sun::star::awt::XDockableWindow']]],
  ['adddoclink',['addDocLink',['../interfacecom_1_1sun_1_1star_1_1sheet_1_1XExternalDocLinks.html#a6cf8807411c4b132393bc80c179af039',1,'com::sun::star::sheet::XExternalDocLinks']]],
  ['adddocumenteventlistener',['addDocumentEventListener',['../interfacecom_1_1sun_1_1star_1_1document_1_1XDocumentEventBroadcaster.html#a2c4521e162663b3594d2f0e374b2b11b',1,'com::sun::star::document::XDocumentEventBroadcaster']]],
  ['adddraggesturelistener',['addDragGestureListener',['../interfacecom_1_1sun_1_1star_1_1datatransfer_1_1dnd_1_1XDragGestureRecognizer.html#a1b1ebc3c1d6e910bb2327fc65b4806da',1,'com::sun::star::datatransfer::dnd::XDragGestureRecognizer']]],
  ['adddrawelement',['addDrawElement',['../interfacecom_1_1sun_1_1star_1_1chart2_1_1XTarget.html#adc44b296fcb690372072712c7eb8692f',1,'com::sun::star::chart2::XTarget']]],
  ['adddroptargetlistener',['addDropTargetListener',['../interfacecom_1_1sun_1_1star_1_1datatransfer_1_1dnd_1_1XDropTarget.html#a422399de6e1002692d07cd87e77f4dc6',1,'com::sun::star::datatransfer::dnd::XDropTarget']]],
  ['addelementcollector',['addElementCollector',['../interfacecom_1_1sun_1_1star_1_1xml_1_1crypto_1_1sax_1_1XSAXEventKeeper.html#a7e7f6919e1504cb97454cc610ff3fe32',1,'com::sun::star::xml::crypto::sax::XSAXEventKeeper']]],
  ['addencryptionresultlistener',['addEncryptionResultListener',['../interfacecom_1_1sun_1_1star_1_1xml_1_1crypto_1_1sax_1_1XEncryptionResultBroadcaster.html#a58cf84177a58e38ee5ca8eaae6ebf901',1,'com::sun::star::xml::crypto::sax::XEncryptionResultBroadcaster']]],
  ['addenginelistener',['addEngineListener',['../interfacecom_1_1sun_1_1star_1_1script_1_1XEngine.html#a03c179e03a6a60370b79a12a838c2f28',1,'com::sun::star::script::XEngine']]],
  ['addenhancedmouseclickhandler',['addEnhancedMouseClickHandler',['../interfacecom_1_1sun_1_1star_1_1sheet_1_1XEnhancedMouseClickBroadcaster.html#ae662d8ed6d0bc977c58f3cbe6c57bd8c',1,'com::sun::star::sheet::XEnhancedMouseClickBroadcaster']]],
  ['addentry',['addEntry',['../interfacecom_1_1sun_1_1star_1_1linguistic2_1_1XConversionDictionary.html#a6d2bb4bf7ebe2a69ba7e45536f07277e',1,'com::sun::star::linguistic2::XConversionDictionary::addEntry()'],['../interfacecom_1_1sun_1_1star_1_1linguistic2_1_1XDictionary.html#aff66d6e1488935d0cfb44d590f5de356',1,'com::sun::star::linguistic2::XDictionary::addEntry()'],['../interfacecom_1_1sun_1_1star_1_1linguistic2_1_1XDictionary1.html#aff66d6e1488935d0cfb44d590f5de356',1,'com::sun::star::linguistic2::XDictionary1::addEntry()']]],
  ['adderrorhandler',['addErrorHandler',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XDisplayConnection.html#a9a0d83a7e9c82dfd004dc84b4ee9061b',1,'com::sun::star::awt::XDisplayConnection']]],
  ['adderrorlistener',['addErrorListener',['../interfacecom_1_1sun_1_1star_1_1form_1_1XErrorBroadcaster.html#a4de37495d43a73a43a0bc8fae9d45232',1,'com::sun::star::form::XErrorBroadcaster']]],
  ['addeventhandler',['addEventHandler',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XDisplayConnection.html#a6758eec781e105237117a4baa56a6609',1,'com::sun::star::awt::XDisplayConnection']]],
  ['addeventlistener',['addEventListener',['../interfacecom_1_1sun_1_1star_1_1lang_1_1XComponent.html#a70a5ec67bcced7a471d56f3a5c98e31a',1,'com::sun::star::lang::XComponent::addEventListener()'],['../interfacecom_1_1sun_1_1star_1_1document_1_1XEventBroadcaster.html#a217f260a04871685320a4b24d48b57be',1,'com::sun::star::document::XEventBroadcaster::addEventListener()'],['../interfacecom_1_1sun_1_1star_1_1xml_1_1dom_1_1events_1_1XEventTarget.html#a12645774c6ae133354db59f75cbb3c18',1,'com::sun::star::xml::dom::events::XEventTarget::addEventListener()']]],
  ['addextension',['addExtension',['../interfacecom_1_1sun_1_1star_1_1deployment_1_1XExtensionManager.html#a1eb6801fc047404af0a52a85a00eb718',1,'com::sun::star::deployment::XExtensionManager']]],
  ['addfilepickerlistener',['addFilePickerListener',['../interfacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1XFilePickerNotifier.html#a95de96f8c3c18694cc4bf5dbcd60ca5d',1,'com::sun::star::ui::dialogs::XFilePickerNotifier']]],
  ['addfiltercontrollerlistener',['addFilterControllerListener',['../interfacecom_1_1sun_1_1star_1_1form_1_1runtime_1_1XFilterController.html#a9eeba5469e2cd4268067dfe07321934d',1,'com::sun::star::form::runtime::XFilterController']]],
  ['addflushlistener',['addFlushListener',['../interfacecom_1_1sun_1_1star_1_1util_1_1XFlushable.html#ae8887e4c65127748b094256f55d1e49a',1,'com::sun::star::util::XFlushable']]],
  ['addfocuslistener',['addFocusListener',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XExtendedToolkit.html#abe1d6890f9685778ec2edefcb386cd6a',1,'com::sun::star::awt::XExtendedToolkit::addFocusListener()'],['../interfacecom_1_1sun_1_1star_1_1awt_1_1XWindow.html#a763278575fdb119824139c5427bba080',1,'com::sun::star::awt::XWindow::addFocusListener()']]],
  ['addformcomponentvaliditylistener',['addFormComponentValidityListener',['../interfacecom_1_1sun_1_1star_1_1form_1_1validation_1_1XValidatableFormComponent.html#a353ca4240bd1c53ac85d20a208317bee',1,'com::sun::star::form::validation::XValidatableFormComponent']]],
  ['addframeactionlistener',['addFrameActionListener',['../interfacecom_1_1sun_1_1star_1_1frame_1_1XFrame.html#a97bda1557ab72b065d20dab24d69ec16',1,'com::sun::star::frame::XFrame']]],
  ['addgridcolumnlistener',['addGridColumnListener',['../interfacecom_1_1sun_1_1star_1_1awt_1_1grid_1_1XGridColumn.html#ac1574f755505c0195259f3d5aa1eed61',1,'com::sun::star::awt::grid::XGridColumn']]],
  ['addgridcontrollistener',['addGridControlListener',['../interfacecom_1_1sun_1_1star_1_1form_1_1XGridControl.html#af47f96b6923b0b125c8f3ad88f29cf80',1,'com::sun::star::form::XGridControl']]],
  ['addgriddatalistener',['addGridDataListener',['../interfacecom_1_1sun_1_1star_1_1awt_1_1grid_1_1XMutableGridDataModel.html#afc4557b96820dab64779954cdc52a7cc',1,'com::sun::star::awt::grid::XMutableGridDataModel']]],
  ['addgroup',['addGroup',['../interfacecom_1_1sun_1_1star_1_1frame_1_1XDocumentTemplates.html#a5aa38b422b26f9a9f4e48ecf5647405c',1,'com::sun::star::frame::XDocumentTemplates']]],
  ['addindex',['addIndex',['../interfacecom_1_1sun_1_1star_1_1sdb_1_1tools_1_1XIndexAlteration.html#ae781ec8fc4fdab70469dc998d4ef7f28',1,'com::sun::star::sdb::tools::XIndexAlteration']]],
  ['addinstance',['addInstance',['../interfacecom_1_1sun_1_1star_1_1configuration_1_1backend_1_1XSchemaHandler.html#a37fd15017ca0aa368bc92a347be8b1d2',1,'com::sun::star::configuration::backend::XSchemaHandler']]],
  ['additem',['addItem',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XComboBox.html#aeaccefb51cf16cb59002f193de78d47d',1,'com::sun::star::awt::XComboBox::addItem()'],['../interfacecom_1_1sun_1_1star_1_1awt_1_1XListBox.html#aeaccefb51cf16cb59002f193de78d47d',1,'com::sun::star::awt::XListBox::addItem()']]],
  ['additemlistener',['addItemListener',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XCheckBox.html#a711aeec4818cf2dbc80db0252c3d021a',1,'com::sun::star::awt::XCheckBox::addItemListener()'],['../interfacecom_1_1sun_1_1star_1_1awt_1_1XComboBox.html#a711aeec4818cf2dbc80db0252c3d021a',1,'com::sun::star::awt::XComboBox::addItemListener()'],['../interfacecom_1_1sun_1_1star_1_1awt_1_1XItemEventBroadcaster.html#a711aeec4818cf2dbc80db0252c3d021a',1,'com::sun::star::awt::XItemEventBroadcaster::addItemListener()'],['../interfacecom_1_1sun_1_1star_1_1awt_1_1XListBox.html#a711aeec4818cf2dbc80db0252c3d021a',1,'com::sun::star::awt::XListBox::addItemListener()'],['../interfacecom_1_1sun_1_1star_1_1awt_1_1XRadioButton.html#a711aeec4818cf2dbc80db0252c3d021a',1,'com::sun::star::awt::XRadioButton::addItemListener()']]],
  ['additemlistlistener',['addItemListListener',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XItemList.html#ade08775aac4a0a4cb1cb8515bb8ea866',1,'com::sun::star::awt::XItemList']]],
  ['additems',['addItems',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XComboBox.html#a58381946105033d66f320708c10df295',1,'com::sun::star::awt::XComboBox::addItems()'],['../interfacecom_1_1sun_1_1star_1_1awt_1_1XListBox.html#a58381946105033d66f320708c10df295',1,'com::sun::star::awt::XListBox::addItems()']]],
  ['additemtype',['addItemType',['../interfacecom_1_1sun_1_1star_1_1configuration_1_1backend_1_1XSchemaHandler.html#a1914bd60d9bd3f507e2f36efa1541cf2',1,'com::sun::star::configuration::backend::XSchemaHandler']]],
  ['addkey',['addKey',['../interfacecom_1_1sun_1_1star_1_1sdb_1_1tools_1_1XKeyAlteration.html#a2c970259c4ad6ef128554e80256c2465',1,'com::sun::star::sdb::tools::XKeyAlteration']]],
  ['addkeyhandler',['addKeyHandler',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XExtendedToolkit.html#a809925223ace2ecea73aa7399a6cc26b',1,'com::sun::star::awt::XExtendedToolkit::addKeyHandler()'],['../interfacecom_1_1sun_1_1star_1_1awt_1_1XUserInputInterception.html#a809925223ace2ecea73aa7399a6cc26b',1,'com::sun::star::awt::XUserInputInterception::addKeyHandler()']]],
  ['addkeylistener',['addKeyListener',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XWindow.html#a9af3815ac9284f4feb77310df0258f7a',1,'com::sun::star::awt::XWindow']]],
  ['addlayoutmanagereventlistener',['addLayoutManagerEventListener',['../interfacecom_1_1sun_1_1star_1_1frame_1_1XLayoutManagerEventBroadcaster.html#afb0f895119cb38176fa847ade0c13fe5',1,'com::sun::star::frame::XLayoutManagerEventBroadcaster']]],
  ['addlinguserviceeventlistener',['addLinguServiceEventListener',['../interfacecom_1_1sun_1_1star_1_1linguistic2_1_1XLinguServiceEventBroadcaster.html#a2f466ba7bfa9f1e0801413dc3c209bb5',1,'com::sun::star::linguistic2::XLinguServiceEventBroadcaster']]],
  ['addlinguservicemanagerlistener',['addLinguServiceManagerListener',['../interfacecom_1_1sun_1_1star_1_1linguistic2_1_1XLinguServiceManager.html#a7ebca6baf4bf1c545870ac0943b1d2e1',1,'com::sun::star::linguistic2::XLinguServiceManager']]],
  ['addlistener',['addListener',['../interfacecom_1_1sun_1_1star_1_1io_1_1XActiveDataControl.html#a1cb99f3608902fc3b6758e21f3d3102d',1,'com::sun::star::io::XActiveDataControl']]],
  ['addlistentrylistener',['addListEntryListener',['../interfacecom_1_1sun_1_1star_1_1form_1_1binding_1_1XListEntrySource.html#a908fb0bb606924890068bc0104253278',1,'com::sun::star::form::binding::XListEntrySource']]],
  ['addloadlistener',['addLoadListener',['../interfacecom_1_1sun_1_1star_1_1form_1_1XLoadable.html#a2664eb513cdbb9cd90b615bdeb5596e9',1,'com::sun::star::form::XLoadable']]],
  ['addlocationtotrustedsources',['addLocationToTrustedSources',['../interfacecom_1_1sun_1_1star_1_1security_1_1XDocumentDigitalSignatures.html#ab958296b9fe2d2e2565d36d8b96a76b4',1,'com::sun::star::security::XDocumentDigitalSignatures']]],
  ['addloghandler',['addLogHandler',['../interfacecom_1_1sun_1_1star_1_1logging_1_1XLogger.html#aa23c8f9d4d3ebb63f46d7d62bd7da3dc',1,'com::sun::star::logging::XLogger']]],
  ['addmailmergeeventlistener',['addMailMergeEventListener',['../interfacecom_1_1sun_1_1star_1_1text_1_1XMailMergeBroadcaster.html#a8260cf5a12b13516abe10a3853471816',1,'com::sun::star::text::XMailMergeBroadcaster']]],
  ['addmenulistener',['addMenuListener',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XMenu.html#a24ddbb11ceb8f7411ee421256a14795d',1,'com::sun::star::awt::XMenu']]],
  ['addmenuproxylistener',['addMenuProxyListener',['../interfacecom_1_1sun_1_1star_1_1mozilla_1_1XMenuProxy.html#ac1f0b08e8fd43d92555a311d3e0739db',1,'com::sun::star::mozilla::XMenuProxy']]],
  ['addmetadatafile',['addMetadataFile',['../interfacecom_1_1sun_1_1star_1_1rdf_1_1XDocumentMetadataAccess.html#aaf839c0cf56b9b4ce56727db13d711f5',1,'com::sun::star::rdf::XDocumentMetadataAccess']]],
  ['addmodechangeapprovelistener',['addModeChangeApproveListener',['../interfacecom_1_1sun_1_1star_1_1util_1_1XModeChangeBroadcaster.html#a36735acc4e4514dec742b8992de5e83f',1,'com::sun::star::util::XModeChangeBroadcaster']]],
  ['addmodechangelistener',['addModeChangeListener',['../interfacecom_1_1sun_1_1star_1_1util_1_1XModeChangeBroadcaster.html#aa941e5eab44274eb697756310fb21a18',1,'com::sun::star::util::XModeChangeBroadcaster']]],
  ['addmodifylistener',['addModifyListener',['../interfacecom_1_1sun_1_1star_1_1util_1_1XModifyBroadcaster.html#a419e56cf6f53f208a01cf7d307a1cc02',1,'com::sun::star::util::XModifyBroadcaster']]],
  ['addmodule',['addModule',['../interfacecom_1_1sun_1_1star_1_1script_1_1XStarBasicAccess.html#a287512fb488dbd9343e42b2a560d7b96',1,'com::sun::star::script::XStarBasicAccess']]],
  ['addmouseclickhandler',['addMouseClickHandler',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XUserInputInterception.html#ad50d348c8d466781e975210b0fcbbb38',1,'com::sun::star::awt::XUserInputInterception']]],
  ['addmouselistener',['addMouseListener',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XWindow.html#a1e044b9120d0e98c33b7ead0b48fe424',1,'com::sun::star::awt::XWindow::addMouseListener()'],['../interfacecom_1_1sun_1_1star_1_1presentation_1_1XSlideShowView.html#a1e044b9120d0e98c33b7ead0b48fe424',1,'com::sun::star::presentation::XSlideShowView::addMouseListener()']]],
  ['addmousemotionlistener',['addMouseMotionListener',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XWindow.html#ae070b13efce39ce3be3ae1c4e79bc28f',1,'com::sun::star::awt::XWindow::addMouseMotionListener()'],['../interfacecom_1_1sun_1_1star_1_1presentation_1_1XSlideShowView.html#ae070b13efce39ce3be3ae1c4e79bc28f',1,'com::sun::star::presentation::XSlideShowView::addMouseMotionListener()']]],
  ['addnew',['addNew',['../interfacecom_1_1sun_1_1star_1_1sheet_1_1XLabelRanges.html#a0ad033b87ffc6cbdddf9a7156cfaad14',1,'com::sun::star::sheet::XLabelRanges::addNew()'],['../interfacecom_1_1sun_1_1star_1_1sheet_1_1XSheetConditionalEntries.html#ae6003e13d9f4a9723070b73f4b62c818',1,'com::sun::star::sheet::XSheetConditionalEntries::addNew()'],['../interfacecom_1_1sun_1_1star_1_1sheet_1_1XSubTotalDescriptor.html#a1bd93b2f4fa33ccac502c026cf7f0211',1,'com::sun::star::sheet::XSubTotalDescriptor::addNew()'],['../interfacecom_1_1sun_1_1star_1_1util_1_1XNumberFormats.html#a59917c16b14b9efcf3aa52d34664ebda',1,'com::sun::star::util::XNumberFormats::addNew()']]],
  ['addnewbyname',['addNewByName',['../interfacecom_1_1sun_1_1star_1_1sheet_1_1XDatabaseRanges.html#ab60de80c3c8cc0e511f524e75da71b27',1,'com::sun::star::sheet::XDatabaseRanges::addNewByName()'],['../interfacecom_1_1sun_1_1star_1_1sheet_1_1XNamedRanges.html#a3c711a36569e35784a4ec1bda04c59f7',1,'com::sun::star::sheet::XNamedRanges::addNewByName()'],['../interfacecom_1_1sun_1_1star_1_1sheet_1_1XScenarios.html#a9fb10e572951e1ff4866b904cca0c31a',1,'com::sun::star::sheet::XScenarios::addNewByName()'],['../interfacecom_1_1sun_1_1star_1_1table_1_1XTableCharts.html#a0792f7036c00cfbec9fa04781de401ce',1,'com::sun::star::table::XTableCharts::addNewByName()'],['../interfacecom_1_1sun_1_1star_1_1table_1_1XTablePivotCharts.html#acece64837d96a30692e5823466f9d805',1,'com::sun::star::table::XTablePivotCharts::addNewByName()']]],
  ['addnewconverted',['addNewConverted',['../interfacecom_1_1sun_1_1star_1_1util_1_1XNumberFormats.html#afcc1a2d6ec3aa6473c5750ddb448f395',1,'com::sun::star::util::XNumberFormats']]],
  ['addnewdictionary',['addNewDictionary',['../interfacecom_1_1sun_1_1star_1_1linguistic2_1_1XConversionDictionaryList.html#a37d678d62d16ebfc693710ddddaa4ade',1,'com::sun::star::linguistic2::XConversionDictionaryList']]],
  ['addnewfromtitles',['addNewFromTitles',['../interfacecom_1_1sun_1_1star_1_1sheet_1_1XNamedRanges.html#abb672a31fc3b27403d5583f272747fee',1,'com::sun::star::sheet::XNamedRanges']]],
  ['addorreplacenode',['addOrReplaceNode',['../interfacecom_1_1sun_1_1star_1_1configuration_1_1backend_1_1XLayerHandler.html#a1aff669824622d5a2e34c8d1fcf030b4',1,'com::sun::star::configuration::backend::XLayerHandler::addOrReplaceNode()'],['../interfacecom_1_1sun_1_1star_1_1configuration_1_1backend_1_1XUpdateHandler.html#a1aff669824622d5a2e34c8d1fcf030b4',1,'com::sun::star::configuration::backend::XUpdateHandler::addOrReplaceNode()']]],
  ['addorreplacenodefromtemplate',['addOrReplaceNodeFromTemplate',['../interfacecom_1_1sun_1_1star_1_1configuration_1_1backend_1_1XLayerHandler.html#af9bcc016d98e17594c95b77493953da5',1,'com::sun::star::configuration::backend::XLayerHandler::addOrReplaceNodeFromTemplate()'],['../interfacecom_1_1sun_1_1star_1_1configuration_1_1backend_1_1XUpdateHandler.html#a1a23908201b8802373a565c4fa966187',1,'com::sun::star::configuration::backend::XUpdateHandler::addOrReplaceNodeFromTemplate()']]],
  ['addorreplaceproperty',['addOrReplaceProperty',['../interfacecom_1_1sun_1_1star_1_1configuration_1_1backend_1_1XUpdateHandler.html#a5bd0d79c693d22565279892dc3ecab21',1,'com::sun::star::configuration::backend::XUpdateHandler']]],
  ['addorreplacepropertywithvalue',['addOrReplacePropertyWithValue',['../interfacecom_1_1sun_1_1star_1_1configuration_1_1backend_1_1XUpdateHandler.html#a18696c86e13e67ddfcdf4440cdbc335c',1,'com::sun::star::configuration::backend::XUpdateHandler']]],
  ['addpackage',['addPackage',['../interfacecom_1_1sun_1_1star_1_1deployment_1_1XPackageManager.html#a47b03bd6f75a3b1fcda1124c8051304b',1,'com::sun::star::deployment::XPackageManager']]],
  ['addpaintlistener',['addPaintListener',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XWindow.html#ac2d3d0d86ad766349c6009586444dc7c',1,'com::sun::star::awt::XWindow::addPaintListener()'],['../interfacecom_1_1sun_1_1star_1_1presentation_1_1XSlideShowView.html#af9121b15344b239fa0ad32b643b1bee9',1,'com::sun::star::presentation::XSlideShowView::addPaintListener()']]],
  ['addparameterlistener',['addParameterListener',['../interfacecom_1_1sun_1_1star_1_1form_1_1XDatabaseParameterBroadcaster.html#af1574e47af370be6f56b96530700ad44',1,'com::sun::star::form::XDatabaseParameterBroadcaster']]],
  ['addpassword',['addPassword',['../interfacecom_1_1sun_1_1star_1_1auth_1_1XSSOPasswordCache.html#a07c78d8fbdd99fbb30e6849d54166a11',1,'com::sun::star::auth::XSSOPasswordCache']]],
  ['addpersistent',['addPersistent',['../interfacecom_1_1sun_1_1star_1_1task_1_1XPasswordContainer.html#a3d1ef8863dbb27e0c0265f60829a3bd2',1,'com::sun::star::task::XPasswordContainer']]],
  ['addpolypolygon',['addPolyPolygon',['../interfacecom_1_1sun_1_1star_1_1rendering_1_1XPolyPolygon2D.html#abc07c3697b3bcbd14abcac098328eb40',1,'com::sun::star::rendering::XPolyPolygon2D']]],
  ['addpreviewcreationnotifylistener',['addPreviewCreationNotifyListener',['../interfacecom_1_1sun_1_1star_1_1drawing_1_1XSlidePreviewCache.html#a52c8455fb5bcd2278a6c22779503bf88',1,'com::sun::star::drawing::XSlidePreviewCache']]],
  ['addprintablelistener',['addPrintableListener',['../interfacecom_1_1sun_1_1star_1_1view_1_1XPrintableBroadcaster.html#a7f6b75d8edd1d0df8cc0727d5284f847',1,'com::sun::star::view::XPrintableBroadcaster']]],
  ['addprintjoblistener',['addPrintJobListener',['../interfacecom_1_1sun_1_1star_1_1view_1_1XPrintJobBroadcaster.html#a8236dc1938be371a19d1744aa4e05144',1,'com::sun::star::view::XPrintJobBroadcaster']]],
  ['addpropertieschangelistener',['addPropertiesChangeListener',['../interfacecom_1_1sun_1_1star_1_1beans_1_1XMultiPropertySet.html#ab2aafcf1921a03822807f9ff2559c206',1,'com::sun::star::beans::XMultiPropertySet::addPropertiesChangeListener()'],['../interfacecom_1_1sun_1_1star_1_1beans_1_1XPropertiesChangeNotifier.html#a3d37bb0d9cea3c9ec39d72c438b08b0f',1,'com::sun::star::beans::XPropertiesChangeNotifier::addPropertiesChangeListener()']]],
  ['addproperty',['addProperty',['../interfacecom_1_1sun_1_1star_1_1beans_1_1XPropertyContainer.html#a988ee408425603aab7f1b249676caeaf',1,'com::sun::star::beans::XPropertyContainer::addProperty()'],['../interfacecom_1_1sun_1_1star_1_1configuration_1_1backend_1_1XLayerHandler.html#a9388873aaceda890e7a74e7517849db2',1,'com::sun::star::configuration::backend::XLayerHandler::addProperty()'],['../interfacecom_1_1sun_1_1star_1_1configuration_1_1backend_1_1XSchemaHandler.html#a9388873aaceda890e7a74e7517849db2',1,'com::sun::star::configuration::backend::XSchemaHandler::addProperty()']]],
  ['addpropertychangelistener',['addPropertyChangeListener',['../interfacecom_1_1sun_1_1star_1_1beans_1_1XPropertySet.html#af4f51dd82bce9dc55256f53577cd50f7',1,'com::sun::star::beans::XPropertySet::addPropertyChangeListener()'],['../interfacecom_1_1sun_1_1star_1_1frame_1_1XConfigManager.html#ae2f3308962522a555163fc01cdf7b80b',1,'com::sun::star::frame::XConfigManager::addPropertyChangeListener()'],['../interfacecom_1_1sun_1_1star_1_1inspection_1_1XPropertyHandler.html#a9349b07cd6685ce6b58377500a2d78e0',1,'com::sun::star::inspection::XPropertyHandler::addPropertyChangeListener()']]],
  ['addpropertysetinfochangelistener',['addPropertySetInfoChangeListener',['../interfacecom_1_1sun_1_1star_1_1beans_1_1XPropertySetInfoChangeNotifier.html#acdbf13de735a71952f910a293d4100f9',1,'com::sun::star::beans::XPropertySetInfoChangeNotifier']]],
  ['addpropertywithdefault',['addPropertyWithDefault',['../interfacecom_1_1sun_1_1star_1_1configuration_1_1backend_1_1XSchemaHandler.html#a3726d558b1818f527e91b2f08c05c4b4',1,'com::sun::star::configuration::backend::XSchemaHandler']]],
  ['addpropertywithvalue',['addPropertyWithValue',['../interfacecom_1_1sun_1_1star_1_1configuration_1_1backend_1_1XLayerHandler.html#a4cf6b43ae24f8a9045b2f6b78a95f99b',1,'com::sun::star::configuration::backend::XLayerHandler']]],
  ['addrangeaddress',['addRangeAddress',['../interfacecom_1_1sun_1_1star_1_1sheet_1_1XSheetCellRangeContainer.html#a111ee349037459a5e0dcb0dbd4a5b61c',1,'com::sun::star::sheet::XSheetCellRangeContainer']]],
  ['addrangeaddresses',['addRangeAddresses',['../interfacecom_1_1sun_1_1star_1_1sheet_1_1XSheetCellRangeContainer.html#a47f1a142dfeed25b237286a4b67f19e2',1,'com::sun::star::sheet::XSheetCellRangeContainer']]],
  ['addranges',['addRanges',['../interfacecom_1_1sun_1_1star_1_1sheet_1_1XScenario.html#ad115901255cd0b4b65a6a33bf261db1d',1,'com::sun::star::sheet::XScenario']]],
  ['addrangeselectionchangelistener',['addRangeSelectionChangeListener',['../interfacecom_1_1sun_1_1star_1_1sheet_1_1XRangeSelection.html#a2c528cfdd3f2116a5e16069647e55d2f',1,'com::sun::star::sheet::XRangeSelection']]],
  ['addrangeselectionlistener',['addRangeSelectionListener',['../interfacecom_1_1sun_1_1star_1_1sheet_1_1XRangeSelection.html#a5c2beff5d23322c892803f82198aca1d',1,'com::sun::star::sheet::XRangeSelection']]],
  ['addrecipient',['addRecipient',['../interfacecom_1_1sun_1_1star_1_1mail_1_1XMailMessage.html#a5dc60097b1688df4c1dfcb764819c3ec',1,'com::sun::star::mail::XMailMessage']]],
  ['addreference',['addReference',['../interfacecom_1_1sun_1_1star_1_1uno_1_1XAdapter.html#ad82a5f0dcb85c847699216f150f45ad9',1,'com::sun::star::uno::XAdapter']]],
  ['addreferenceresolvedlistener',['addReferenceResolvedListener',['../interfacecom_1_1sun_1_1star_1_1xml_1_1crypto_1_1sax_1_1XReferenceResolvedBroadcaster.html#af6e8cd915d44fa9890981b13b4907657',1,'com::sun::star::xml::crypto::sax::XReferenceResolvedBroadcaster']]],
  ['addrefreshlistener',['addRefreshListener',['../interfacecom_1_1sun_1_1star_1_1util_1_1XRefreshable.html#afba35ac103d79954de9e0b5c8b516802',1,'com::sun::star::util::XRefreshable']]],
  ['addregressioncurve',['addRegressionCurve',['../interfacecom_1_1sun_1_1star_1_1chart2_1_1XRegressionCurveContainer.html#a2d5138e2949471c03852a8dc77a8106a',1,'com::sun::star::chart2::XRegressionCurveContainer']]],
  ['addremotecontentprovider',['addRemoteContentProvider',['../interfacecom_1_1sun_1_1star_1_1ucb_1_1XRemoteContentProviderAcceptor.html#a73358827a3ac91349847ae85f340e480',1,'com::sun::star::ucb::XRemoteContentProviderAcceptor']]],
  ['addremotecontentproviderchangelistener',['addRemoteContentProviderChangeListener',['../interfacecom_1_1sun_1_1star_1_1ucb_1_1XRemoteContentProviderChangeNotifier.html#ae6ac21ae2c41cb32ca184ed9c36db9bb',1,'com::sun::star::ucb::XRemoteContentProviderChangeNotifier']]],
  ['addresetlistener',['addResetListener',['../interfacecom_1_1sun_1_1star_1_1form_1_1XReset.html#a4096ec4a4c8b89daa2748e7e36ace9dd',1,'com::sun::star::form::XReset']]],
  ['addresource',['addResource',['../interfacecom_1_1sun_1_1star_1_1drawing_1_1framework_1_1XConfiguration.html#a16a92912af095ef5432af78a15001c4b',1,'com::sun::star::drawing::framework::XConfiguration']]],
  ['addresourcefactory',['addResourceFactory',['../interfacecom_1_1sun_1_1star_1_1drawing_1_1framework_1_1XResourceFactoryManager.html#ab68b7c2605b4b50b3eecf04a270c2134',1,'com::sun::star::drawing::framework::XResourceFactoryManager']]],
  ['addresultlistener',['addResultListener',['../interfacecom_1_1sun_1_1star_1_1sheet_1_1XVolatileResult.html#a153a0c6f456bdd25a1d47960c0a0f63e',1,'com::sun::star::sheet::XVolatileResult']]],
  ['addrow',['addRow',['../interfacecom_1_1sun_1_1star_1_1awt_1_1grid_1_1XMutableGridDataModel.html#a12d27ffff5111c1f9325eb7713fc5744',1,'com::sun::star::awt::grid::XMutableGridDataModel']]],
  ['addrows',['addRows',['../interfacecom_1_1sun_1_1star_1_1awt_1_1grid_1_1XMutableGridDataModel.html#a552027ecdbaf49f2466f0223abe4025f',1,'com::sun::star::awt::grid::XMutableGridDataModel']]],
  ['addrowschangelistener',['addRowsChangeListener',['../interfacecom_1_1sun_1_1star_1_1sdb_1_1XRowsChangeBroadcaster.html#ae0cc67f823c1f081e599d583d1190954',1,'com::sun::star::sdb::XRowsChangeBroadcaster']]],
  ['addrowsetapprovelistener',['addRowSetApproveListener',['../interfacecom_1_1sun_1_1star_1_1sdb_1_1XRowSetApproveBroadcaster.html#ab50b00e45cdd8757164b96a11e95128c',1,'com::sun::star::sdb::XRowSetApproveBroadcaster']]],
  ['addrowsetchangelistener',['addRowSetChangeListener',['../interfacecom_1_1sun_1_1star_1_1sdb_1_1XRowSetChangeBroadcaster.html#a09a62271c63c952d881c44471acd1e03',1,'com::sun::star::sdb::XRowSetChangeBroadcaster']]],
  ['addrowsetlistener',['addRowSetListener',['../interfacecom_1_1sun_1_1star_1_1sdbc_1_1XRowSet.html#aebe26cd56ea7ad74deb02c0eed42e1f3',1,'com::sun::star::sdbc::XRowSet']]],
  ['addsaxeventkeeperstatuschangelistener',['addSAXEventKeeperStatusChangeListener',['../interfacecom_1_1sun_1_1star_1_1xml_1_1crypto_1_1sax_1_1XSAXEventKeeperStatusChangeBroadcaster.html#a784f9ec5a517e76cd3128a6969b44279',1,'com::sun::star::xml::crypto::sax::XSAXEventKeeperStatusChangeBroadcaster']]],
  ['addscriptlistener',['addScriptListener',['../interfacecom_1_1sun_1_1star_1_1script_1_1XEventAttacherManager.html#ae2428a9905b2957c0923945da2620a69',1,'com::sun::star::script::XEventAttacherManager']]],
  ['addsecurityelementcollector',['addSecurityElementCollector',['../interfacecom_1_1sun_1_1star_1_1xml_1_1crypto_1_1sax_1_1XSecuritySAXEventKeeper.html#ace85f29137a8a1e3b9f05a23c6ddea22',1,'com::sun::star::xml::crypto::sax::XSecuritySAXEventKeeper']]],
  ['addsecurityenvironment',['addSecurityEnvironment',['../interfacecom_1_1sun_1_1star_1_1xml_1_1crypto_1_1XXMLSecurityContext.html#ae8f60bc15eef9b5bfc2fcfd7873ddc6d',1,'com::sun::star::xml::crypto::XXMLSecurityContext']]],
  ['addselection',['addSelection',['../interfacecom_1_1sun_1_1star_1_1accessibility_1_1XAccessibleTextSelection.html#a47eb6c342ca08cf0634d0cef2b8a9497',1,'com::sun::star::accessibility::XAccessibleTextSelection::addSelection()'],['../interfacecom_1_1sun_1_1star_1_1view_1_1XMultiSelectionSupplier.html#a4ad9b54af8988e9e48e4063f141069f5',1,'com::sun::star::view::XMultiSelectionSupplier::addSelection()']]],
  ['addselectionchangelistener',['addSelectionChangeListener',['../interfacecom_1_1sun_1_1star_1_1chart2_1_1data_1_1XRangeHighlighter.html#aea7bc42b322aa3b07eea3cc0d254da71',1,'com::sun::star::chart2::data::XRangeHighlighter::addSelectionChangeListener()'],['../interfacecom_1_1sun_1_1star_1_1view_1_1XSelectionSupplier.html#aea7bc42b322aa3b07eea3cc0d254da71',1,'com::sun::star::view::XSelectionSupplier::addSelectionChangeListener()']]],
  ['addselectionlistener',['addSelectionListener',['../interfacecom_1_1sun_1_1star_1_1awt_1_1grid_1_1XGridRowSelection.html#afce56177e29a07ffc2019a2ce0cd6f8a',1,'com::sun::star::awt::grid::XGridRowSelection']]],
  ['addsessionmanagerlistener',['addSessionManagerListener',['../interfacecom_1_1sun_1_1star_1_1frame_1_1XSessionManagerClient.html#a92a191324673afac3946aa42c7a675ba',1,'com::sun::star::frame::XSessionManagerClient']]],
  ['addshape',['addShape',['../interfacecom_1_1sun_1_1star_1_1chart2_1_1XChartShapeContainer.html#a3de1e4719bf42d5b727e7867f9cd2544',1,'com::sun::star::chart2::XChartShapeContainer']]],
  ['addshapeeventlistener',['addShapeEventListener',['../interfacecom_1_1sun_1_1star_1_1presentation_1_1XSlideShow.html#ac337a7888beb33e0f5b512d223104b05',1,'com::sun::star::presentation::XSlideShow']]],
  ['addsheetcache',['addSheetCache',['../interfacecom_1_1sun_1_1star_1_1sheet_1_1XExternalDocLink.html#a6f41bd654a62328a634624cccba0fd68',1,'com::sun::star::sheet::XExternalDocLink']]],
  ['addsignaturecreationresultlistener',['addSignatureCreationResultListener',['../interfacecom_1_1sun_1_1star_1_1xml_1_1crypto_1_1sax_1_1XSignatureCreationResultBroadcaster.html#ab14c57294f09b8295c1c5240944ea902',1,'com::sun::star::xml::crypto::sax::XSignatureCreationResultBroadcaster']]],
  ['addsignatureverifyresultlistener',['addSignatureVerifyResultListener',['../interfacecom_1_1sun_1_1star_1_1xml_1_1crypto_1_1sax_1_1XSignatureVerifyResultBroadcaster.html#aedf5643d0a54876a41073e18bc76ed92',1,'com::sun::star::xml::crypto::sax::XSignatureVerifyResultBroadcaster']]],
  ['addslideshowlistener',['addSlideShowListener',['../interfacecom_1_1sun_1_1star_1_1presentation_1_1XSlideShow.html#a8ed314ae4bb87ab9306c0d8f5fbfc035',1,'com::sun::star::presentation::XSlideShow::addSlideShowListener()'],['../interfacecom_1_1sun_1_1star_1_1presentation_1_1XSlideShowController.html#ad7d4e8a11234a03b14b73bdca3cc2ce3',1,'com::sun::star::presentation::XSlideShowController::addSlideShowListener()']]],
  ['addspinlistener',['addSpinListener',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XSpinField.html#aa200914d4a261d2c010096fcf7a8019f',1,'com::sun::star::awt::XSpinField']]],
  ['addsqlerrorlistener',['addSQLErrorListener',['../interfacecom_1_1sun_1_1star_1_1sdb_1_1XSQLErrorBroadcaster.html#a47adc46dea4eca1e214703209ff5efc9',1,'com::sun::star::sdb::XSQLErrorBroadcaster']]],
  ['addstatechangelistener',['addStateChangeListener',['../interfacecom_1_1sun_1_1star_1_1embed_1_1XStateChangeBroadcaster.html#aea6c8e5b04f5f896b96c2cf6edde1c25',1,'com::sun::star::embed::XStateChangeBroadcaster']]],
  ['addstatement',['addStatement',['../interfacecom_1_1sun_1_1star_1_1rdf_1_1XNamedGraph.html#a41a4ed5894c4905ec62b0502994d131e',1,'com::sun::star::rdf::XNamedGraph']]],
  ['addstatuslistener',['addStatusListener',['../interfacecom_1_1sun_1_1star_1_1frame_1_1XDispatch.html#ad445cdfc5ae6e3a90e2e52d602ea07b0',1,'com::sun::star::frame::XDispatch']]],
  ['addstoragechangelistener',['addStorageChangeListener',['../interfacecom_1_1sun_1_1star_1_1document_1_1XStorageBasedDocument.html#aa0c8d369e77e4fdaf3a03ba3edac1814',1,'com::sun::star::document::XStorageBasedDocument']]],
  ['addstreamlistener',['addStreamListener',['../interfacecom_1_1sun_1_1star_1_1connection_1_1XConnectionBroadcaster.html#a7d6753624c9ad451d09fdc74c9da97d6',1,'com::sun::star::connection::XConnectionBroadcaster']]],
  ['addstylechangelistener',['addStyleChangeListener',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XStyleSettings.html#a32bfa1c58908e2c418ddfb9e1850bcb1',1,'com::sun::star::awt::XStyleSettings']]],
  ['addsubmissionvetolistener',['addSubmissionVetoListener',['../interfacecom_1_1sun_1_1star_1_1form_1_1submission_1_1XSubmission.html#aa776223003f5197f9f191586f5d806a0',1,'com::sun::star::form::submission::XSubmission']]],
  ['addsubmitlistener',['addSubmitListener',['../interfacecom_1_1sun_1_1star_1_1form_1_1XSubmit.html#ae4b00f70e68b0a7fd979468cff9941f5',1,'com::sun::star::form::XSubmit']]],
  ['addtabbarbuttonafter',['addTabBarButtonAfter',['../interfacecom_1_1sun_1_1star_1_1drawing_1_1framework_1_1XTabBar.html#a21a8bdbbb85512b4e5a026fff7ecc238',1,'com::sun::star::drawing::framework::XTabBar']]],
  ['addtabcontroller',['addTabController',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XUnoControlContainer.html#a457c3917f7b9ad7b5104a8a80c5bfc77',1,'com::sun::star::awt::XUnoControlContainer']]],
  ['addtablistener',['addTabListener',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XSimpleTabController.html#a99567a1799ebb9da29005f43d452347e',1,'com::sun::star::awt::XSimpleTabController']]],
  ['addtabpagecontainerlistener',['addTabPageContainerListener',['../interfacecom_1_1sun_1_1star_1_1awt_1_1tab_1_1XTabPageContainer.html#a30979717eaabe51229dcd8ac84f3be95',1,'com::sun::star::awt::tab::XTabPageContainer']]],
  ['addtemplate',['addTemplate',['../interfacecom_1_1sun_1_1star_1_1frame_1_1XDocumentTemplates.html#a5363efb93117fbedd2dd6beb28242569',1,'com::sun::star::frame::XDocumentTemplates']]],
  ['addterminatelistener',['addTerminateListener',['../interfacecom_1_1sun_1_1star_1_1frame_1_1XDesktop.html#a6eac4a452fd1f860cadeb8204f489dba',1,'com::sun::star::frame::XDesktop']]],
  ['addtext',['addText',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XProgressMonitor.html#a2691e3721505ea46499cd9de04ee7dc4',1,'com::sun::star::awt::XProgressMonitor']]],
  ['addtextlistener',['addTextListener',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XTextComponent.html#a3b1b9fe71c13651bc329a2b7f95bbade',1,'com::sun::star::awt::XTextComponent']]],
  ['addtitlechangelistener',['addTitleChangeListener',['../interfacecom_1_1sun_1_1star_1_1frame_1_1XTitleChangeBroadcaster.html#a27b78b049ab3a962570ef84a66c20cb8',1,'com::sun::star::frame::XTitleChangeBroadcaster']]],
  ['addtop',['addTop',['../interfacecom_1_1sun_1_1star_1_1drawing_1_1XShapes2.html#a57750456be913dd8235bfee8678dd94c',1,'com::sun::star::drawing::XShapes2']]],
  ['addtopwindowlistener',['addTopWindowListener',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XExtendedToolkit.html#a3157d6b441fa1c158a0af83c749bc6d4',1,'com::sun::star::awt::XExtendedToolkit::addTopWindowListener()'],['../interfacecom_1_1sun_1_1star_1_1awt_1_1XTopWindow.html#ab7d6cd17c0ee033522af72a76a3ae4f0',1,'com::sun::star::awt::XTopWindow::addTopWindowListener()']]],
  ['addtransactionlistener',['addTransactionListener',['../interfacecom_1_1sun_1_1star_1_1embed_1_1XTransactionBroadcaster.html#ad3fe6566514f33afd9bbd7a203a7b8cf',1,'com::sun::star::embed::XTransactionBroadcaster']]],
  ['addtransformationchangedlistener',['addTransformationChangedListener',['../interfacecom_1_1sun_1_1star_1_1presentation_1_1XSlideShowView.html#a9896e738f1d7c12d3769f84b7bd3f034',1,'com::sun::star::presentation::XSlideShowView']]],
  ['addtreedatamodellistener',['addTreeDataModelListener',['../interfacecom_1_1sun_1_1star_1_1awt_1_1tree_1_1XTreeDataModel.html#aba9d0dfec03d9f47f99550ac6c3e023e',1,'com::sun::star::awt::tree::XTreeDataModel']]],
  ['addtreeeditlistener',['addTreeEditListener',['../interfacecom_1_1sun_1_1star_1_1awt_1_1tree_1_1XTreeControl.html#ab9d26d28eb97f9b64ba9621a879c6a84',1,'com::sun::star::awt::tree::XTreeControl']]],
  ['addtreeexpansionlistener',['addTreeExpansionListener',['../interfacecom_1_1sun_1_1star_1_1awt_1_1tree_1_1XTreeControl.html#a0c6aeb5ca502311c4d6cddaf6934a540',1,'com::sun::star::awt::tree::XTreeControl']]],
  ['addundoaction',['addUndoAction',['../interfacecom_1_1sun_1_1star_1_1document_1_1XUndoManager.html#a262e384c635e25c891341af0377a3032',1,'com::sun::star::document::XUndoManager']]],
  ['addundomanagerlistener',['addUndoManagerListener',['../interfacecom_1_1sun_1_1star_1_1document_1_1XUndoManager.html#a67a300a9f7cd91e09f1e4fc36420075d',1,'com::sun::star::document::XUndoManager']]],
  ['addupdatelistener',['addUpdateListener',['../interfacecom_1_1sun_1_1star_1_1form_1_1XUpdateBroadcaster.html#a9609bd854cd251d8318ced313ead3e88',1,'com::sun::star::form::XUpdateBroadcaster']]],
  ['addurl',['addUrl',['../interfacecom_1_1sun_1_1star_1_1task_1_1XUrlContainer.html#a03cd74d6c707caa7bc4e561304fdefeb',1,'com::sun::star::task::XUrlContainer']]],
  ['addvalidityconstraintlistener',['addValidityConstraintListener',['../interfacecom_1_1sun_1_1star_1_1form_1_1validation_1_1XValidator.html#a5f59c8eb6e4b1acf567dae2232f60620',1,'com::sun::star::form::validation::XValidator']]],
  ['addvalue',['addValue',['../interfacecom_1_1sun_1_1star_1_1i18n_1_1XCalendar.html#a5c51823c61126269397c54012e9940d3',1,'com::sun::star::i18n::XCalendar']]],
  ['addvbascriptlistener',['addVBAScriptListener',['../interfacecom_1_1sun_1_1star_1_1script_1_1vba_1_1XVBACompatibility.html#a21bb6a9d95921b3e18ad4264a9018b75',1,'com::sun::star::script::vba::XVBACompatibility']]],
  ['addvclcontainerlistener',['addVclContainerListener',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XVclContainer.html#a61ab7c4a49df25362848c990842acd14',1,'com::sun::star::awt::XVclContainer']]],
  ['addvetoablechangelistener',['addVetoableChangeListener',['../interfacecom_1_1sun_1_1star_1_1beans_1_1XPropertySet.html#aa1a86e8ed694e00dfc756b14b546eda1',1,'com::sun::star::beans::XPropertySet']]],
  ['addview',['addView',['../interfacecom_1_1sun_1_1star_1_1presentation_1_1XSlideShow.html#aeb413aa9a597bbdac38e53303b08249b',1,'com::sun::star::presentation::XSlideShow']]],
  ['addwindowlistener',['addWindowListener',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XWindow.html#aeb5ce79a127144106dccda247fd6c9ed',1,'com::sun::star::awt::XWindow']]],
  ['addwithimplicitid',['addWithImplicitID',['../interfacecom_1_1sun_1_1star_1_1container_1_1XImplicitIDContainer.html#ab1f516095cf4e7ce40689dd7e9df97e0',1,'com::sun::star::container::XImplicitIDContainer']]],
  ['adjustmentvaluechanged',['adjustmentValueChanged',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XAdjustmentListener.html#afb0bd209717c07e4e7f8c681694fe64d',1,'com::sun::star::awt::XAdjustmentListener']]],
  ['advanceto',['advanceTo',['../interfacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1XWizard.html#a4e06416411c79dd14b63f3983b326190',1,'com::sun::star::ui::dialogs::XWizard']]],
  ['advise',['advise',['../interfacecom_1_1sun_1_1star_1_1lang_1_1XConnectionPoint.html#a0331c710da22857ced9b2067f0fd74b0',1,'com::sun::star::lang::XConnectionPoint::advise()'],['../interfacecom_1_1sun_1_1star_1_1lang_1_1XConnectionPointContainer.html#abb8c562b201482b635f941f57d3ffe0d',1,'com::sun::star::lang::XConnectionPointContainer::advise()']]],
  ['afterlast',['afterLast',['../interfacecom_1_1sun_1_1star_1_1sdbc_1_1XResultSet.html#a4220bd65ccca989e491fc4e75c3ac6e3',1,'com::sun::star::sdbc::XResultSet']]],
  ['alignshapes',['alignShapes',['../interfacecom_1_1sun_1_1star_1_1drawing_1_1XShapeAligner.html#a160845d4c3cd104939166e034f3022ea',1,'com::sun::star::drawing::XShapeAligner']]],
  ['allactionscleared',['allActionsCleared',['../interfacecom_1_1sun_1_1star_1_1document_1_1XUndoManagerListener.html#a123b583f319b865beb2e4868e246f78c',1,'com::sun::star::document::XUndoManagerListener']]],
  ['allentrieschanged',['allEntriesChanged',['../interfacecom_1_1sun_1_1star_1_1form_1_1binding_1_1XListEntryListener.html#a62236670c0a35a3acdd60d05c3080c2f',1,'com::sun::star::form::binding::XListEntryListener']]],
  ['allitemsremoved',['allItemsRemoved',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XItemListListener.html#a6670e12a4d5e69bd51b0c7f6233ffc95',1,'com::sun::star::awt::XItemListListener']]],
  ['allowlinebreak',['allowLineBreak',['../interfacecom_1_1sun_1_1star_1_1xml_1_1sax_1_1XExtendedDocumentHandler.html#ac415a427ae393ebf4ead6eb84bcb2090',1,'com::sun::star::xml::sax::XExtendedDocumentHandler']]],
  ['allowpersistentstoring',['allowPersistentStoring',['../interfacecom_1_1sun_1_1star_1_1task_1_1XMasterPasswordHandling.html#ad95acad92f04fb2e6db315fae44d3b86',1,'com::sun::star::task::XMasterPasswordHandling']]],
  ['allproceduresarecallable',['allProceduresAreCallable',['../interfacecom_1_1sun_1_1star_1_1sdbc_1_1XDatabaseMetaData.html#a74240a53ecf8b25ceb385a85ad18f3da',1,'com::sun::star::sdbc::XDatabaseMetaData']]],
  ['alltablesareselectable',['allTablesAreSelectable',['../interfacecom_1_1sun_1_1star_1_1sdbc_1_1XDatabaseMetaData.html#a7a662769bff87a36b91a64589468d6a5',1,'com::sun::star::sdbc::XDatabaseMetaData']]],
  ['altercolumnbyindex',['alterColumnByIndex',['../interfacecom_1_1sun_1_1star_1_1sdbcx_1_1XAlterTable.html#a31995c40a85928be16ff1ec5cc5ca182',1,'com::sun::star::sdbcx::XAlterTable']]],
  ['altercolumnbyname',['alterColumnByName',['../interfacecom_1_1sun_1_1star_1_1sdb_1_1tools_1_1XTableAlteration.html#a0178ff13b411abc792ca9b1d309128ea',1,'com::sun::star::sdb::tools::XTableAlteration::alterColumnByName()'],['../interfacecom_1_1sun_1_1star_1_1sdbcx_1_1XAlterTable.html#a1792b78bd619d0d319388ac116df4011',1,'com::sun::star::sdbcx::XAlterTable::alterColumnByName()']]],
  ['altercommand',['alterCommand',['../interfacecom_1_1sun_1_1star_1_1sdb_1_1tools_1_1XViewAccess.html#a575a4ccb502083eb23011fc39d887037',1,'com::sun::star::sdb::tools::XViewAccess::alterCommand()'],['../interfacecom_1_1sun_1_1star_1_1sdb_1_1XAlterQuery.html#a3bb987676a59916d50d6a308b69f2d96',1,'com::sun::star::sdb::XAlterQuery::alterCommand()'],['../interfacecom_1_1sun_1_1star_1_1sdbcx_1_1XAlterView.html#a253e0c5d44930e01e2664d9dcd592855',1,'com::sun::star::sdbcx::XAlterView::alterCommand()']]],
  ['append',['append',['../interfacecom_1_1sun_1_1star_1_1frame_1_1XFrames.html#acbe30cc1ce05262e7a43545363439812',1,'com::sun::star::frame::XFrames']]],
  ['appendbydescriptor',['appendByDescriptor',['../interfacecom_1_1sun_1_1star_1_1sdbcx_1_1XAppend.html#a74d17dee8402e5b7ede73636ddfce62b',1,'com::sun::star::sdbcx::XAppend']]],
  ['appendchild',['appendChild',['../interfacecom_1_1sun_1_1star_1_1animations_1_1XTimeContainer.html#af62bd6e9bc5b8f4147a091a9c29ddd67',1,'com::sun::star::animations::XTimeContainer::appendChild()'],['../interfacecom_1_1sun_1_1star_1_1awt_1_1tree_1_1XMutableTreeNode.html#a60a0c810fa518a346c8135571656709e',1,'com::sun::star::awt::tree::XMutableTreeNode::appendChild()'],['../interfacecom_1_1sun_1_1star_1_1xml_1_1dom_1_1XNode.html#a5c0adf13188936619e4dfb636adb6a2f',1,'com::sun::star::xml::dom::XNode::appendChild()']]],
  ['appenddata',['appendData',['../interfacecom_1_1sun_1_1star_1_1xml_1_1dom_1_1XCharacterData.html#afeeb74b5488625cb104f6a4892371d5d',1,'com::sun::star::xml::dom::XCharacterData']]],
  ['appendemptydisjunctiveterm',['appendEmptyDisjunctiveTerm',['../interfacecom_1_1sun_1_1star_1_1form_1_1runtime_1_1XFilterController.html#a3470aa686dc2f42360375a3e501038fc',1,'com::sun::star::form::runtime::XFilterController']]],
  ['appendfilter',['appendFilter',['../interfacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1XFilterManager.html#ae6c608a77c755b24972d5d8abbddc1d4',1,'com::sun::star::ui::dialogs::XFilterManager']]],
  ['appendfilterbycolumn',['appendFilterByColumn',['../interfacecom_1_1sun_1_1star_1_1sdb_1_1XSingleSelectQueryComposer.html#a775b31c0fdbe7ef9284d37303b8dd95a',1,'com::sun::star::sdb::XSingleSelectQueryComposer::appendFilterByColumn()'],['../interfacecom_1_1sun_1_1star_1_1sdb_1_1XSQLQueryComposer.html#a9b18fdf74b45432013719766f20f80e9',1,'com::sun::star::sdb::XSQLQueryComposer::appendFilterByColumn()']]],
  ['appendfiltergroup',['appendFilterGroup',['../interfacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1XFilterGroupManager.html#ab08eeed36f60dc31614acf5f32fe7ae5',1,'com::sun::star::ui::dialogs::XFilterGroupManager']]],
  ['appendgroupbycolumn',['appendGroupByColumn',['../interfacecom_1_1sun_1_1star_1_1sdb_1_1XSingleSelectQueryComposer.html#a648f70c26079abaac487e2b59eaad57c',1,'com::sun::star::sdb::XSingleSelectQueryComposer']]],
  ['appendhavingclausebycolumn',['appendHavingClauseByColumn',['../interfacecom_1_1sun_1_1star_1_1sdb_1_1XSingleSelectQueryComposer.html#a05cacbf03e4b5bb7428574f1707abc6e',1,'com::sun::star::sdb::XSingleSelectQueryComposer']]],
  ['appendlistentry',['appendListEntry',['../interfacecom_1_1sun_1_1star_1_1inspection_1_1XStringListControl.html#a1c2fac71d01569750412b43126424783',1,'com::sun::star::inspection::XStringListControl']]],
  ['appendorderbycolumn',['appendOrderByColumn',['../interfacecom_1_1sun_1_1star_1_1sdb_1_1XSingleSelectQueryComposer.html#aa8cee7548668952177c86459058c328e',1,'com::sun::star::sdb::XSingleSelectQueryComposer::appendOrderByColumn()'],['../interfacecom_1_1sun_1_1star_1_1sdb_1_1XSQLQueryComposer.html#aa8cee7548668952177c86459058c328e',1,'com::sun::star::sdb::XSQLQueryComposer::appendOrderByColumn()']]],
  ['appendsequence',['appendSequence',['../interfacecom_1_1sun_1_1star_1_1chart2_1_1XInternalDataProvider.html#a93bce9d0d78a70fe871bb7c463add211',1,'com::sun::star::chart2::XInternalDataProvider']]],
  ['appendtabbarbutton',['appendTabBarButton',['../interfacecom_1_1sun_1_1star_1_1drawing_1_1framework_1_1XTabBar.html#a351bd91f7936de0b0c5a9b5f7073c981',1,'com::sun::star::drawing::framework::XTabBar']]],
  ['appendtextcontent',['appendTextContent',['../interfacecom_1_1sun_1_1star_1_1text_1_1XTextContentAppend.html#ad718d68d3048f6088845c2fc8149b2d5',1,'com::sun::star::text::XTextContentAppend']]],
  ['appendtextportion',['appendTextPortion',['../interfacecom_1_1sun_1_1star_1_1text_1_1XTextPortionAppend.html#aafae2528f90fde19a6ba2141ae884712',1,'com::sun::star::text::XTextPortionAppend']]],
  ['apply',['apply',['../interfacecom_1_1sun_1_1star_1_1sheet_1_1XScenario.html#a95067243b72a23863ec07c821797455c',1,'com::sun::star::sheet::XScenario']]],
  ['applybrightnesscontrast',['applyBrightnessContrast',['../interfacecom_1_1sun_1_1star_1_1graphic_1_1XGraphicTransformer.html#a209dbf2c583783ce67889725dfe3d8d0',1,'com::sun::star::graphic::XGraphicTransformer']]],
  ['applyduotone',['applyDuotone',['../interfacecom_1_1sun_1_1star_1_1graphic_1_1XGraphicTransformer.html#a10a41a5050c959578f1cc8bf5cffa77f',1,'com::sun::star::graphic::XGraphicTransformer']]],
  ['applylogicaladvancements',['applyLogicalAdvancements',['../interfacecom_1_1sun_1_1star_1_1rendering_1_1XTextLayout.html#a07cf67fa72a3c948e373614bbd1a758f',1,'com::sun::star::rendering::XTextLayout']]],
  ['applystyle',['applyStyle',['../interfacecom_1_1sun_1_1star_1_1chart2_1_1XChartTypeTemplate.html#ad71d21712fdfeead41f40195a2ef9f7f',1,'com::sun::star::chart2::XChartTypeTemplate']]],
  ['applysubtotals',['applySubTotals',['../interfacecom_1_1sun_1_1star_1_1sheet_1_1XSubTotalCalculatable.html#a499cba2596ca3d1aa81a96107ec39489',1,'com::sun::star::sheet::XSubTotalCalculatable']]],
  ['applyto',['applyTo',['../interfacecom_1_1sun_1_1star_1_1text_1_1XAutoTextEntry.html#a9b970443282f4d34d6b3914b1211654b',1,'com::sun::star::text::XAutoTextEntry']]],
  ['approveaction',['approveAction',['../interfacecom_1_1sun_1_1star_1_1embed_1_1XActionsApproval.html#abaae6aa7a315e52c35f86a047bf42e95',1,'com::sun::star::embed::XActionsApproval::approveAction()'],['../interfacecom_1_1sun_1_1star_1_1form_1_1XApproveActionListener.html#a783ef57d57eba3fe8d04afbf855e6f13',1,'com::sun::star::form::XApproveActionListener::approveAction()']]],
  ['approveconnectionclosing',['approveConnectionClosing',['../interfacecom_1_1sun_1_1star_1_1sdb_1_1XDatabaseAccessListener.html#a594bcd748c5ba79be9fb11fbb1e37f0c',1,'com::sun::star::sdb::XDatabaseAccessListener']]],
  ['approvecursormove',['approveCursorMove',['../interfacecom_1_1sun_1_1star_1_1sdb_1_1XRowSetApproveListener.html#a39f7f01b353a197652bfc2017ee03dac',1,'com::sun::star::sdb::XRowSetApproveListener']]],
  ['approvedelete',['approveDelete',['../interfacecom_1_1sun_1_1star_1_1form_1_1XDeleteListener.html#ad91e0952164bb70b935e5cc340d1aa32',1,'com::sun::star::form::XDeleteListener']]],
  ['approvefiring',['approveFiring',['../interfacecom_1_1sun_1_1star_1_1script_1_1XAllListener.html#a91b35667ef07d81bfea5b27f21791289',1,'com::sun::star::script::XAllListener::approveFiring()'],['../interfacecom_1_1sun_1_1star_1_1script_1_1XScriptListener.html#a27a0ac3ed0e725ab24d6cd55e085bea1',1,'com::sun::star::script::XScriptListener::approveFiring()']]],
  ['approveinsertelement',['approveInsertElement',['../interfacecom_1_1sun_1_1star_1_1container_1_1XContainerApproveListener.html#ac9e90b272d7ec617747f32a6dc7da884',1,'com::sun::star::container::XContainerApproveListener']]],
  ['approveinteraction',['approveInteraction',['../interfacecom_1_1sun_1_1star_1_1frame_1_1XSessionManagerListener.html#ad5844411a4f4f448d5830ad3caddf84e',1,'com::sun::star::frame::XSessionManagerListener']]],
  ['approvemodechange',['approveModeChange',['../interfacecom_1_1sun_1_1star_1_1util_1_1XModeChangeApproveListener.html#aad86cb66e928b4f241dcb290b4bf1738',1,'com::sun::star::util::XModeChangeApproveListener']]],
  ['approveparameter',['approveParameter',['../interfacecom_1_1sun_1_1star_1_1form_1_1XDatabaseParameterListener.html#aa834a80dcc3a99ad0ce65cbdcb369045',1,'com::sun::star::form::XDatabaseParameterListener']]],
  ['approveremoveelement',['approveRemoveElement',['../interfacecom_1_1sun_1_1star_1_1container_1_1XContainerApproveListener.html#a86fd9efa4722a1dab43c54dc5576a8b3',1,'com::sun::star::container::XContainerApproveListener']]],
  ['approvereplaceelement',['approveReplaceElement',['../interfacecom_1_1sun_1_1star_1_1container_1_1XContainerApproveListener.html#acd9c101943ffc04be340a9490dc47376',1,'com::sun::star::container::XContainerApproveListener']]],
  ['approvereset',['approveReset',['../interfacecom_1_1sun_1_1star_1_1form_1_1XResetListener.html#a106884ab903f53331befcdcdda3d4dfe',1,'com::sun::star::form::XResetListener']]],
  ['approverowchange',['approveRowChange',['../interfacecom_1_1sun_1_1star_1_1sdb_1_1XRowSetApproveListener.html#aefa576828c4976c84c17f7ec01641122',1,'com::sun::star::sdb::XRowSetApproveListener']]],
  ['approverowsetchange',['approveRowSetChange',['../interfacecom_1_1sun_1_1star_1_1sdb_1_1XRowSetApproveListener.html#a196defd8441a20e2f6f7229f2e2dd122',1,'com::sun::star::sdb::XRowSetApproveListener']]],
  ['approvesubmit',['approveSubmit',['../interfacecom_1_1sun_1_1star_1_1form_1_1XSubmitListener.html#a25bbc923432ba3183fc8581bf3c2d65a',1,'com::sun::star::form::XSubmitListener']]],
  ['approveupdate',['approveUpdate',['../interfacecom_1_1sun_1_1star_1_1form_1_1XUpdateListener.html#a5ea561cd11564dc64e9233d60fee3c0b',1,'com::sun::star::form::XUpdateListener']]],
  ['arrange',['arrange',['../interfacecom_1_1sun_1_1star_1_1drawing_1_1XShapeArranger.html#a50ab0be3a93871ff1eeaec920cca6935',1,'com::sun::star::drawing::XShapeArranger::arrange()'],['../interfacecom_1_1sun_1_1star_1_1frame_1_1XWindowArranger.html#af88ac9c2b1b1c0d584ad6b6be8289b00',1,'com::sun::star::frame::XWindowArranger::arrange()']]],
  ['arrangewindowshorizontal',['arrangeWindowsHorizontal',['../interfacecom_1_1sun_1_1star_1_1frame_1_1XTask.html#a70ce6b2ef2ff1c8e6fb3a71d3607486e',1,'com::sun::star::frame::XTask']]],
  ['arrangewindowsvertical',['arrangeWindowsVertical',['../interfacecom_1_1sun_1_1star_1_1frame_1_1XTask.html#a2170fa2717b261f2766a57f1183db479',1,'com::sun::star::frame::XTask']]],
  ['assemble',['assemble',['../interfacecom_1_1sun_1_1star_1_1util_1_1XURLTransformer.html#af87908ac4cf1abb1cb9859ccb8ab9cc2',1,'com::sun::star::util::XURLTransformer']]],
  ['attach',['attach',['../interfacecom_1_1sun_1_1star_1_1script_1_1XEventAttacherManager.html#ae6977ae5b73ec7ebe9209cd2d96321e0',1,'com::sun::star::script::XEventAttacherManager::attach()'],['../interfacecom_1_1sun_1_1star_1_1text_1_1XTextContent.html#a15b73364f8298e5547e76c79e5c19e8e',1,'com::sun::star::text::XTextContent::attach()']]],
  ['attachdata',['attachData',['../interfacecom_1_1sun_1_1star_1_1chart_1_1XChartDocument.html#ac84c1a5ca9c589b85ae7615d577b2ee4',1,'com::sun::star::chart::XChartDocument']]],
  ['attachdataprovider',['attachDataProvider',['../interfacecom_1_1sun_1_1star_1_1chart2_1_1data_1_1XDataReceiver.html#afce447a14c3a1da357671e3f33dc9fa9',1,'com::sun::star::chart2::data::XDataReceiver']]],
  ['attachevents',['attachEvents',['../interfacecom_1_1sun_1_1star_1_1script_1_1XScriptEventsAttacher.html#a578dd1dcf15d6c47e10437a5943a7082',1,'com::sun::star::script::XScriptEventsAttacher']]],
  ['attachframe',['attachFrame',['../interfacecom_1_1sun_1_1star_1_1frame_1_1XController.html#a208c7a58951a8d43ccb89e40864fa042',1,'com::sun::star::frame::XController::attachFrame()'],['../interfacecom_1_1sun_1_1star_1_1frame_1_1XLayoutManager.html#a9a3ca2a2864a13cfb20ab2ba8eedd446',1,'com::sun::star::frame::XLayoutManager::attachFrame()']]],
  ['attachlistener',['attachListener',['../interfacecom_1_1sun_1_1star_1_1script_1_1XEventAttacher.html#a67a00732c68cca5035901f05df8d74a3',1,'com::sun::star::script::XEventAttacher']]],
  ['attachmodel',['attachModel',['../interfacecom_1_1sun_1_1star_1_1frame_1_1XController.html#aa846f9cb39e61eda2e240a74412df538',1,'com::sun::star::frame::XController']]],
  ['attachmultipleeventlisteners',['attachMultipleEventListeners',['../interfacecom_1_1sun_1_1star_1_1script_1_1XEventAttacher2.html#a20bda78f75a6101b19395bc0366e5e49',1,'com::sun::star::script::XEventAttacher2']]],
  ['attachnumberformatssupplier',['attachNumberFormatsSupplier',['../interfacecom_1_1sun_1_1star_1_1chart2_1_1data_1_1XDataReceiver.html#a7093de9fd407c657790e6ded900e8f1b',1,'com::sun::star::chart2::data::XDataReceiver::attachNumberFormatsSupplier()'],['../interfacecom_1_1sun_1_1star_1_1util_1_1XNumberFormatter.html#a7093de9fd407c657790e6ded900e8f1b',1,'com::sun::star::util::XNumberFormatter::attachNumberFormatsSupplier()']]],
  ['attachresource',['attachResource',['../interfacecom_1_1sun_1_1star_1_1frame_1_1XModel.html#ae1742058db43afeacee88a09b0040ac5',1,'com::sun::star::frame::XModel']]],
  ['attachshapetolayer',['attachShapeToLayer',['../interfacecom_1_1sun_1_1star_1_1drawing_1_1XLayerManager.html#a15f310584084d7fd9f030b6714a9371e',1,'com::sun::star::drawing::XLayerManager']]],
  ['attachsingleeventlistener',['attachSingleEventListener',['../interfacecom_1_1sun_1_1star_1_1script_1_1XEventAttacher.html#aff01a36d1dbeb6fb0f4e03a242509873',1,'com::sun::star::script::XEventAttacher']]],
  ['attachtextfieldmaster',['attachTextFieldMaster',['../interfacecom_1_1sun_1_1star_1_1text_1_1XDependentTextField.html#af606b16efc30ab33830bcc0ea20887d1',1,'com::sun::star::text::XDependentTextField']]],
  ['attachtourl',['attachToURL',['../interfacecom_1_1sun_1_1star_1_1embed_1_1XOptimizedStorage.html#a4b3149e1f2a70d97d861b56311d671fc',1,'com::sun::star::embed::XOptimizedStorage']]],
  ['authorizatewithmasterpassword',['authorizateWithMasterPassword',['../interfacecom_1_1sun_1_1star_1_1task_1_1XMasterPasswordHandling.html#a411befc248c519f2883b06a01691f9bb',1,'com::sun::star::task::XMasterPasswordHandling']]],
  ['autoformat',['autoFormat',['../interfacecom_1_1sun_1_1star_1_1table_1_1XAutoFormattable.html#a2b3c53fd7551136b8134cff90c644132',1,'com::sun::star::table::XAutoFormattable']]],
  ['autooutline',['autoOutline',['../interfacecom_1_1sun_1_1star_1_1sheet_1_1XSheetOutline.html#ac286d91ba977fe583071dfbe317f75fe',1,'com::sun::star::sheet::XSheetOutline']]],
  ['autoscroll',['autoscroll',['../interfacecom_1_1sun_1_1star_1_1datatransfer_1_1dnd_1_1XAutoscroll.html#adf442fefb7e2887efb7533f330b67406',1,'com::sun::star::datatransfer::dnd::XAutoscroll']]],
  ['autotaborder',['autoTabOrder',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XTabController.html#ae5a22b749ca5e859e89829e8cbbd179b',1,'com::sun::star::awt::XTabController']]],
  ['available',['available',['../interfacecom_1_1sun_1_1star_1_1connection_1_1XConnection2.html#a58d11e5f2a0bbbe9da90752980bf3d03',1,'com::sun::star::connection::XConnection2::available()'],['../interfacecom_1_1sun_1_1star_1_1io_1_1XInputStream.html#a58d11e5f2a0bbbe9da90752980bf3d03',1,'com::sun::star::io::XInputStream::available()']]]
];
